Class: Aws::NeptuneGraph::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::NeptuneGraph::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-neptunegraph/client.rb
Overview
An API client for NeptuneGraph. To construct a client, you need to configure a :region and :credentials.
client = Aws::NeptuneGraph::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_export_task(params = {}) ⇒ Types::CancelExportTaskOutput
Cancel the specified export task.
-
#cancel_import_task(params = {}) ⇒ Types::CancelImportTaskOutput
Deletes the specified import task.
-
#cancel_query(params = {}) ⇒ Struct
Cancels a specified query.
-
#create_graph(params = {}) ⇒ Types::CreateGraphOutput
Creates a new Neptune Analytics graph.
-
#create_graph_snapshot(params = {}) ⇒ Types::CreateGraphSnapshotOutput
Creates a snapshot of the specific graph.
-
#create_graph_using_import_task(params = {}) ⇒ Types::CreateGraphUsingImportTaskOutput
Creates a new Neptune Analytics graph and imports data into it, either from Amazon Simple Storage Service (S3) or from a Neptune database or a Neptune database snapshot.
-
#create_private_graph_endpoint(params = {}) ⇒ Types::CreatePrivateGraphEndpointOutput
Create a private graph endpoint to allow private access to the graph from within a VPC.
-
#delete_graph(params = {}) ⇒ Types::DeleteGraphOutput
Deletes the specified graph.
-
#delete_graph_snapshot(params = {}) ⇒ Types::DeleteGraphSnapshotOutput
Deletes the specified graph snapshot.
-
#delete_private_graph_endpoint(params = {}) ⇒ Types::DeletePrivateGraphEndpointOutput
Deletes a private graph endpoint.
-
#execute_query(params = {}) ⇒ Types::ExecuteQueryOutput
Execute an openCypher query.
-
#get_export_task(params = {}) ⇒ Types::GetExportTaskOutput
Retrieves a specified export task.
-
#get_graph(params = {}) ⇒ Types::GetGraphOutput
Gets information about a specified graph.
-
#get_graph_snapshot(params = {}) ⇒ Types::GetGraphSnapshotOutput
Retrieves a specified graph snapshot.
-
#get_graph_summary(params = {}) ⇒ Types::GetGraphSummaryOutput
Gets a graph summary for a property graph.
-
#get_import_task(params = {}) ⇒ Types::GetImportTaskOutput
Retrieves a specified import task.
-
#get_private_graph_endpoint(params = {}) ⇒ Types::GetPrivateGraphEndpointOutput
Retrieves information about a specified private endpoint.
-
#get_query(params = {}) ⇒ Types::GetQueryOutput
Retrieves the status of a specified query.
-
#list_export_tasks(params = {}) ⇒ Types::ListExportTasksOutput
Retrieves a list of export tasks.
-
#list_graph_snapshots(params = {}) ⇒ Types::ListGraphSnapshotsOutput
Lists available snapshots of a specified Neptune Analytics graph.
-
#list_graphs(params = {}) ⇒ Types::ListGraphsOutput
Lists available Neptune Analytics graphs.
-
#list_import_tasks(params = {}) ⇒ Types::ListImportTasksOutput
Lists import tasks.
-
#list_private_graph_endpoints(params = {}) ⇒ Types::ListPrivateGraphEndpointsOutput
Lists private endpoints for a specified Neptune Analytics graph.
-
#list_queries(params = {}) ⇒ Types::ListQueriesOutput
Lists active openCypher queries.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists tags associated with a specified resource.
-
#reset_graph(params = {}) ⇒ Types::ResetGraphOutput
Empties the data from a specified Neptune Analytics graph.
-
#restore_graph_from_snapshot(params = {}) ⇒ Types::RestoreGraphFromSnapshotOutput
Restores a graph from a snapshot.
-
#start_export_task(params = {}) ⇒ Types::StartExportTaskOutput
Export data from an existing Neptune Analytics graph to Amazon S3.
-
#start_graph(params = {}) ⇒ Types::StartGraphOutput
Starts the specific graph.
-
#start_import_task(params = {}) ⇒ Types::StartImportTaskOutput
Import data into existing Neptune Analytics graph from Amazon Simple Storage Service (S3).
-
#stop_graph(params = {}) ⇒ Types::StopGraphOutput
Stops the specific graph.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
-
#update_graph(params = {}) ⇒ Types::UpdateGraphOutput
Updates the configuration of a specified Neptune Analytics graph.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2716 2717 2718 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 2716 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2719 2720 2721 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 2719 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 2570 2571 2572 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 2556 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::NeptuneGraph') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-neptunegraph' context[:gem_version] = '1.46.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_export_task(params = {}) ⇒ Types::CancelExportTaskOutput
Cancel the specified export task.
518 519 520 521 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 518 def cancel_export_task(params = {}, = {}) req = build_request(:cancel_export_task, params) req.send_request() end |
#cancel_import_task(params = {}) ⇒ Types::CancelImportTaskOutput
Deletes the specified import task.
558 559 560 561 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 558 def cancel_import_task(params = {}, = {}) req = build_request(:cancel_import_task, params) req.send_request() end |
#cancel_query(params = {}) ⇒ Struct
Cancels a specified query.
584 585 586 587 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 584 def cancel_query(params = {}, = {}) req = build_request(:cancel_query, params) req.send_request() end |
#create_graph(params = {}) ⇒ Types::CreateGraphOutput
Creates a new Neptune Analytics graph.
688 689 690 691 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 688 def create_graph(params = {}, = {}) req = build_request(:create_graph, params) req.send_request() end |
#create_graph_snapshot(params = {}) ⇒ Types::CreateGraphSnapshotOutput
Creates a snapshot of the specific graph.
744 745 746 747 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 744 def create_graph_snapshot(params = {}, = {}) req = build_request(:create_graph_snapshot, params) req.send_request() end |
#create_graph_using_import_task(params = {}) ⇒ Types::CreateGraphUsingImportTaskOutput
Creates a new Neptune Analytics graph and imports data into it, either from Amazon Simple Storage Service (S3) or from a Neptune database or a Neptune database snapshot.
The data can be loaded from files in S3 that in either the [Gremlin CSV format] or the [openCypher load format].
[1]: docs.aws.amazon.com/neptune/latest/userguide/bulk-load-tutorial-format-gremlin.html [2]: docs.aws.amazon.com/neptune/latest/userguide/bulk-load-tutorial-format-opencypher.html
919 920 921 922 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 919 def create_graph_using_import_task(params = {}, = {}) req = build_request(:create_graph_using_import_task, params) req.send_request() end |
#create_private_graph_endpoint(params = {}) ⇒ Types::CreatePrivateGraphEndpointOutput
Create a private graph endpoint to allow private access to the graph from within a VPC. You can attach security groups to the private graph endpoint.
<note markdown=“1”> VPC endpoint charges apply.
</note>
972 973 974 975 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 972 def create_private_graph_endpoint(params = {}, = {}) req = build_request(:create_private_graph_endpoint, params) req.send_request() end |
#delete_graph(params = {}) ⇒ Types::DeleteGraphOutput
Deletes the specified graph. Graphs cannot be deleted if delete-protection is enabled.
1036 1037 1038 1039 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1036 def delete_graph(params = {}, = {}) req = build_request(:delete_graph, params) req.send_request() end |
#delete_graph_snapshot(params = {}) ⇒ Types::DeleteGraphSnapshotOutput
Deletes the specified graph snapshot.
1076 1077 1078 1079 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1076 def delete_graph_snapshot(params = {}, = {}) req = build_request(:delete_graph_snapshot, params) req.send_request() end |
#delete_private_graph_endpoint(params = {}) ⇒ Types::DeletePrivateGraphEndpointOutput
Deletes a private graph endpoint.
1115 1116 1117 1118 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1115 def delete_private_graph_endpoint(params = {}, = {}) req = build_request(:delete_private_graph_endpoint, params) req.send_request() end |
#execute_query(params = {}) ⇒ Types::ExecuteQueryOutput
Execute an openCypher query.
When invoking this operation in a Neptune Analytics cluster, the IAM user or role making the request must have a policy attached that allows one of the following IAM actions in that cluster, depending on the query:
-
neptune-graph:ReadDataViaQuery
-
neptune-graph:WriteDataViaQuery
-
neptune-graph:DeleteDataViaQuery
1189 1190 1191 1192 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1189 def execute_query(params = {}, = {}, &block) req = build_request(:execute_query, params) req.send_request(, &block) end |
#get_export_task(params = {}) ⇒ Types::GetExportTaskOutput
Retrieves a specified export task.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* export_task_cancelled
* export_task_successful
1256 1257 1258 1259 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1256 def get_export_task(params = {}, = {}) req = build_request(:get_export_task, params) req.send_request() end |
#get_graph(params = {}) ⇒ Types::GetGraphOutput
Gets information about a specified graph.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* graph_available
* graph_deleted
* graph_stopped
1319 1320 1321 1322 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1319 def get_graph(params = {}, = {}) req = build_request(:get_graph, params) req.send_request() end |
#get_graph_snapshot(params = {}) ⇒ Types::GetGraphSnapshotOutput
Retrieves a specified graph snapshot.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* graph_snapshot_available
* graph_snapshot_deleted
1365 1366 1367 1368 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1365 def get_graph_snapshot(params = {}, = {}) req = build_request(:get_graph_snapshot, params) req.send_request() end |
#get_graph_summary(params = {}) ⇒ Types::GetGraphSummaryOutput
Gets a graph summary for a property graph.
1429 1430 1431 1432 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1429 def get_graph_summary(params = {}, = {}) req = build_request(:get_graph_summary, params) req.send_request() end |
#get_import_task(params = {}) ⇒ Types::GetImportTaskOutput
Retrieves a specified import task.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* import_task_cancelled
* import_task_successful
1493 1494 1495 1496 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1493 def get_import_task(params = {}, = {}) req = build_request(:get_import_task, params) req.send_request() end |
#get_private_graph_endpoint(params = {}) ⇒ Types::GetPrivateGraphEndpointOutput
Retrieves information about a specified private endpoint.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* private_graph_endpoint_available
* private_graph_endpoint_deleted
1538 1539 1540 1541 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1538 def get_private_graph_endpoint(params = {}, = {}) req = build_request(:get_private_graph_endpoint, params) req.send_request() end |
#get_query(params = {}) ⇒ Types::GetQueryOutput
Retrieves the status of a specified query.
<note markdown=“1”> When invoking this operation in a Neptune Analytics cluster, the IAM user or role making the request must have the neptune-graph:GetQueryStatus IAM action attached.
</note>
1584 1585 1586 1587 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1584 def get_query(params = {}, = {}) req = build_request(:get_query, params) req.send_request() end |
#list_export_tasks(params = {}) ⇒ Types::ListExportTasksOutput
Retrieves a list of export tasks.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1633 1634 1635 1636 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1633 def list_export_tasks(params = {}, = {}) req = build_request(:list_export_tasks, params) req.send_request() end |
#list_graph_snapshots(params = {}) ⇒ Types::ListGraphSnapshotsOutput
Lists available snapshots of a specified Neptune Analytics graph.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1690 1691 1692 1693 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1690 def list_graph_snapshots(params = {}, = {}) req = build_request(:list_graph_snapshots, params) req.send_request() end |
#list_graphs(params = {}) ⇒ Types::ListGraphsOutput
Lists available Neptune Analytics graphs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1746 1747 1748 1749 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1746 def list_graphs(params = {}, = {}) req = build_request(:list_graphs, params) req.send_request() end |
#list_import_tasks(params = {}) ⇒ Types::ListImportTasksOutput
Lists import tasks.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1799 1800 1801 1802 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1799 def list_import_tasks(params = {}, = {}) req = build_request(:list_import_tasks, params) req.send_request() end |
#list_private_graph_endpoints(params = {}) ⇒ Types::ListPrivateGraphEndpointsOutput
Lists private endpoints for a specified Neptune Analytics graph.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1854 1855 1856 1857 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1854 def list_private_graph_endpoints(params = {}, = {}) req = build_request(:list_private_graph_endpoints, params) req.send_request() end |
#list_queries(params = {}) ⇒ Types::ListQueriesOutput
Lists active openCypher queries.
1895 1896 1897 1898 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1895 def list_queries(params = {}, = {}) req = build_request(:list_queries, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Lists tags associated with a specified resource.
1924 1925 1926 1927 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1924 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#reset_graph(params = {}) ⇒ Types::ResetGraphOutput
Empties the data from a specified Neptune Analytics graph.
1987 1988 1989 1990 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 1987 def reset_graph(params = {}, = {}) req = build_request(:reset_graph, params) req.send_request() end |
#restore_graph_from_snapshot(params = {}) ⇒ Types::RestoreGraphFromSnapshotOutput
Restores a graph from a snapshot.
2086 2087 2088 2089 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 2086 def restore_graph_from_snapshot(params = {}, = {}) req = build_request(:restore_graph_from_snapshot, params) req.send_request() end |
#start_export_task(params = {}) ⇒ Types::StartExportTaskOutput
Export data from an existing Neptune Analytics graph to Amazon S3. The graph state should be AVAILABLE.
2196 2197 2198 2199 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 2196 def start_export_task(params = {}, = {}) req = build_request(:start_export_task, params) req.send_request() end |
#start_graph(params = {}) ⇒ Types::StartGraphOutput
Starts the specific graph.
2252 2253 2254 2255 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 2252 def start_graph(params = {}, = {}) req = build_request(:start_graph, params) req.send_request() end |
#start_import_task(params = {}) ⇒ Types::StartImportTaskOutput
Import data into existing Neptune Analytics graph from Amazon Simple Storage Service (S3). The graph needs to be empty and in the AVAILABLE state.
2348 2349 2350 2351 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 2348 def start_import_task(params = {}, = {}) req = build_request(:start_import_task, params) req.send_request() end |
#stop_graph(params = {}) ⇒ Types::StopGraphOutput
Stops the specific graph.
2404 2405 2406 2407 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 2404 def stop_graph(params = {}, = {}) req = build_request(:stop_graph, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
2446 2447 2448 2449 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 2446 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
2472 2473 2474 2475 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 2472 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_graph(params = {}) ⇒ Types::UpdateGraphOutput
Updates the configuration of a specified Neptune Analytics graph
2547 2548 2549 2550 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 2547 def update_graph(params = {}, = {}) req = build_request(:update_graph, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts | | ——————————– | ———————————– | ——– | ————- | | export_task_cancelled | #get_export_task | 60 | 60 | | export_task_successful | #get_export_task | 60 | 480 | | graph_available | #get_graph | 60 | 480 | | graph_deleted | #get_graph | 60 | 60 | | graph_snapshot_available | #get_graph_snapshot | 60 | 120 | | graph_snapshot_deleted | #get_graph_snapshot | 60 | 60 | | graph_stopped | #get_graph | 20 | 90 | | import_task_cancelled | #get_import_task | 60 | 60 | | import_task_successful | #get_import_task | 60 | 480 | | private_graph_endpoint_available | #get_private_graph_endpoint | 10 | 180 | | private_graph_endpoint_deleted | #get_private_graph_endpoint | 10 | 180 |
2672 2673 2674 2675 2676 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 2672 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2680 2681 2682 |
# File 'lib/aws-sdk-neptunegraph/client.rb', line 2680 def waiter_names waiters.keys end |