Class: Aws::NeptuneGraph::Types::CreateGraphOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-neptunegraph/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The ARN of the graph.

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-neptunegraph/types.rb', line 338

class CreateGraphOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :status_reason,
  :create_time,
  :provisioned_memory,
  :endpoint,
  :public_connectivity,
  :vector_search_configuration,
  :replica_count,
  :kms_key_identifier,
  :source_snapshot_id,
  :deletion_protection,
  :build_number)
  SENSITIVE = []
  include Aws::Structure
end

#build_numberString

The build number of the graph software.

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-neptunegraph/types.rb', line 338

class CreateGraphOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :status_reason,
  :create_time,
  :provisioned_memory,
  :endpoint,
  :public_connectivity,
  :vector_search_configuration,
  :replica_count,
  :kms_key_identifier,
  :source_snapshot_id,
  :deletion_protection,
  :build_number)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time when the graph was created.

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-neptunegraph/types.rb', line 338

class CreateGraphOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :status_reason,
  :create_time,
  :provisioned_memory,
  :endpoint,
  :public_connectivity,
  :vector_search_configuration,
  :replica_count,
  :kms_key_identifier,
  :source_snapshot_id,
  :deletion_protection,
  :build_number)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protectionBoolean

A value that indicates whether the graph has deletion protection enabled. The graph can’t be deleted when deletion protection is enabled.

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-neptunegraph/types.rb', line 338

class CreateGraphOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :status_reason,
  :create_time,
  :provisioned_memory,
  :endpoint,
  :public_connectivity,
  :vector_search_configuration,
  :replica_count,
  :kms_key_identifier,
  :source_snapshot_id,
  :deletion_protection,
  :build_number)
  SENSITIVE = []
  include Aws::Structure
end

#endpointString

The graph endpoint.

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-neptunegraph/types.rb', line 338

class CreateGraphOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :status_reason,
  :create_time,
  :provisioned_memory,
  :endpoint,
  :public_connectivity,
  :vector_search_configuration,
  :replica_count,
  :kms_key_identifier,
  :source_snapshot_id,
  :deletion_protection,
  :build_number)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the graph.

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-neptunegraph/types.rb', line 338

class CreateGraphOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :status_reason,
  :create_time,
  :provisioned_memory,
  :endpoint,
  :public_connectivity,
  :vector_search_configuration,
  :replica_count,
  :kms_key_identifier,
  :source_snapshot_id,
  :deletion_protection,
  :build_number)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_identifierString

Specifies the KMS key used to encrypt data in the new graph.

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-neptunegraph/types.rb', line 338

class CreateGraphOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :status_reason,
  :create_time,
  :provisioned_memory,
  :endpoint,
  :public_connectivity,
  :vector_search_configuration,
  :replica_count,
  :kms_key_identifier,
  :source_snapshot_id,
  :deletion_protection,
  :build_number)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The graph name. For example: my-graph-1.

The name must contain from 1 to 63 letters, numbers, or hyphens, and its first character must be a letter. It cannot end with a hyphen or contain two consecutive hyphens. Only lowercase letters are allowed.

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-neptunegraph/types.rb', line 338

class CreateGraphOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :status_reason,
  :create_time,
  :provisioned_memory,
  :endpoint,
  :public_connectivity,
  :vector_search_configuration,
  :replica_count,
  :kms_key_identifier,
  :source_snapshot_id,
  :deletion_protection,
  :build_number)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_memoryInteger

The provisioned memory-optimized Neptune Capacity Units (m-NCUs) to use for the graph.

Min = 16

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-neptunegraph/types.rb', line 338

class CreateGraphOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :status_reason,
  :create_time,
  :provisioned_memory,
  :endpoint,
  :public_connectivity,
  :vector_search_configuration,
  :replica_count,
  :kms_key_identifier,
  :source_snapshot_id,
  :deletion_protection,
  :build_number)
  SENSITIVE = []
  include Aws::Structure
end

#public_connectivityBoolean

Specifies whether or not the graph can be reachable over the internet. All access to graphs is IAM authenticated.

<note markdown=“1”> If enabling public connectivity for the first time, there will be a delay while it is enabled.

</note>

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-neptunegraph/types.rb', line 338

class CreateGraphOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :status_reason,
  :create_time,
  :provisioned_memory,
  :endpoint,
  :public_connectivity,
  :vector_search_configuration,
  :replica_count,
  :kms_key_identifier,
  :source_snapshot_id,
  :deletion_protection,
  :build_number)
  SENSITIVE = []
  include Aws::Structure
end

#replica_countInteger

The number of replicas in other AZs.

Default: If not specified, the default value is 1.

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-neptunegraph/types.rb', line 338

class CreateGraphOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :status_reason,
  :create_time,
  :provisioned_memory,
  :endpoint,
  :public_connectivity,
  :vector_search_configuration,
  :replica_count,
  :kms_key_identifier,
  :source_snapshot_id,
  :deletion_protection,
  :build_number)
  SENSITIVE = []
  include Aws::Structure
end

#source_snapshot_idString

The ID of the source graph.

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-neptunegraph/types.rb', line 338

class CreateGraphOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :status_reason,
  :create_time,
  :provisioned_memory,
  :endpoint,
  :public_connectivity,
  :vector_search_configuration,
  :replica_count,
  :kms_key_identifier,
  :source_snapshot_id,
  :deletion_protection,
  :build_number)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the graph.

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-neptunegraph/types.rb', line 338

class CreateGraphOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :status_reason,
  :create_time,
  :provisioned_memory,
  :endpoint,
  :public_connectivity,
  :vector_search_configuration,
  :replica_count,
  :kms_key_identifier,
  :source_snapshot_id,
  :deletion_protection,
  :build_number)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

The reason the status was given.

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-neptunegraph/types.rb', line 338

class CreateGraphOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :status_reason,
  :create_time,
  :provisioned_memory,
  :endpoint,
  :public_connectivity,
  :vector_search_configuration,
  :replica_count,
  :kms_key_identifier,
  :source_snapshot_id,
  :deletion_protection,
  :build_number)
  SENSITIVE = []
  include Aws::Structure
end

#vector_search_configurationTypes::VectorSearchConfiguration

The vector-search configuration for the graph, which specifies the vector dimension to use in the vector index, if any.

Returns:



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/aws-sdk-neptunegraph/types.rb', line 338

class CreateGraphOutput < Struct.new(
  :id,
  :name,
  :arn,
  :status,
  :status_reason,
  :create_time,
  :provisioned_memory,
  :endpoint,
  :public_connectivity,
  :vector_search_configuration,
  :replica_count,
  :kms_key_identifier,
  :source_snapshot_id,
  :deletion_protection,
  :build_number)
  SENSITIVE = []
  include Aws::Structure
end