Class: Aws::NeptuneGraph::Types::GetImportTaskOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-neptunegraph/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attempt_numberInteger

The number of the current attempts to execute the import task.

Returns:

  • (Integer)


1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-neptunegraph/types.rb', line 1515

class GetImportTaskOutput < Struct.new(
  :graph_id,
  :task_id,
  :source,
  :format,
  :parquet_type,
  :role_arn,
  :status,
  :import_options,
  :import_task_details,
  :attempt_number,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#formatString

Specifies the format of S3 data to be imported. Valid values are CSV, which identifies the [Gremlin CSV format] or OPENCYPHER, which identifies the [openCypher load format].

[1]: docs.aws.amazon.com/neptune/latest/userguide/bulk-load-tutorial-format-gremlin.html [2]: docs.aws.amazon.com/neptune/latest/userguide/bulk-load-tutorial-format-opencypher.html

Returns:

  • (String)


1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-neptunegraph/types.rb', line 1515

class GetImportTaskOutput < Struct.new(
  :graph_id,
  :task_id,
  :source,
  :format,
  :parquet_type,
  :role_arn,
  :status,
  :import_options,
  :import_task_details,
  :attempt_number,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#graph_idString

The unique identifier of the Neptune Analytics graph.

Returns:

  • (String)


1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-neptunegraph/types.rb', line 1515

class GetImportTaskOutput < Struct.new(
  :graph_id,
  :task_id,
  :source,
  :format,
  :parquet_type,
  :role_arn,
  :status,
  :import_options,
  :import_task_details,
  :attempt_number,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#import_optionsTypes::ImportOptions

Contains options for controlling the import process. For example, if the failOnError key is set to false, the import skips problem data and attempts to continue (whereas if set to true, the default, or if omitted, the import operation halts immediately when an error is encountered.



1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-neptunegraph/types.rb', line 1515

class GetImportTaskOutput < Struct.new(
  :graph_id,
  :task_id,
  :source,
  :format,
  :parquet_type,
  :role_arn,
  :status,
  :import_options,
  :import_task_details,
  :attempt_number,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#import_task_detailsTypes::ImportTaskDetails

Contains details about the specified import task.



1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-neptunegraph/types.rb', line 1515

class GetImportTaskOutput < Struct.new(
  :graph_id,
  :task_id,
  :source,
  :format,
  :parquet_type,
  :role_arn,
  :status,
  :import_options,
  :import_task_details,
  :attempt_number,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#parquet_typeString

The parquet type of the import task.

Returns:

  • (String)


1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-neptunegraph/types.rb', line 1515

class GetImportTaskOutput < Struct.new(
  :graph_id,
  :task_id,
  :source,
  :format,
  :parquet_type,
  :role_arn,
  :status,
  :import_options,
  :import_task_details,
  :attempt_number,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the IAM role that will allow access to the data that is to be imported.

Returns:

  • (String)


1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-neptunegraph/types.rb', line 1515

class GetImportTaskOutput < Struct.new(
  :graph_id,
  :task_id,
  :source,
  :format,
  :parquet_type,
  :role_arn,
  :status,
  :import_options,
  :import_task_details,
  :attempt_number,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

A URL identifying to the location of the data to be imported. This can be an Amazon S3 path, or can point to a Neptune database endpoint or snapshot

Returns:

  • (String)


1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-neptunegraph/types.rb', line 1515

class GetImportTaskOutput < Struct.new(
  :graph_id,
  :task_id,
  :source,
  :format,
  :parquet_type,
  :role_arn,
  :status,
  :import_options,
  :import_task_details,
  :attempt_number,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the import task:

  • INITIALIZING   –   The necessary resources needed to create the graph are being prepared.

  • ANALYZING_DATA   –   The data is being analyzed to determine the optimal infrastructure configuration for the new graph.

  • RE_PROVISIONING   –   The data did not fit into the provisioned graph, so it is being re-provisioned with more capacity.

  • IMPORTING   –   The data is being loaded.

  • ERROR_ENCOUNTERED   –   An error has been encountered while trying to create the graph and import the data.

  • ERROR_ENCOUNTERED_ROLLING_BACK   –   Because of the error that was encountered, the graph is being rolled back and all its resources released.

  • SUCCEEDED   –   Graph creation and data loading succeeded.

  • FAILED   –   Graph creation or data loading failed. When the status is FAILED, you can use get-graphs to get more information about the state of the graph.

  • CANCELLING   –   Because you cancelled the import task, cancellation is in progress.

  • CANCELLED   –   You have successfully cancelled the import task.

Returns:

  • (String)


1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-neptunegraph/types.rb', line 1515

class GetImportTaskOutput < Struct.new(
  :graph_id,
  :task_id,
  :source,
  :format,
  :parquet_type,
  :role_arn,
  :status,
  :import_options,
  :import_task_details,
  :attempt_number,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

The reason that the import task has this status value.

Returns:

  • (String)


1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-neptunegraph/types.rb', line 1515

class GetImportTaskOutput < Struct.new(
  :graph_id,
  :task_id,
  :source,
  :format,
  :parquet_type,
  :role_arn,
  :status,
  :import_options,
  :import_task_details,
  :attempt_number,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#task_idString

The unique identifier of the import task.

Returns:

  • (String)


1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
# File 'lib/aws-sdk-neptunegraph/types.rb', line 1515

class GetImportTaskOutput < Struct.new(
  :graph_id,
  :task_id,
  :source,
  :format,
  :parquet_type,
  :role_arn,
  :status,
  :import_options,
  :import_task_details,
  :attempt_number,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end