Class: Aws::NeptuneGraph::Types::ListQueriesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::NeptuneGraph::Types::ListQueriesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-neptunegraph/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#graph_identifier ⇒ String
The unique identifier of the Neptune Analytics graph.
-
#max_results ⇒ Integer
The maximum number of results to be fetched by the API.
-
#state ⇒ String
Filtered list of queries based on state.
Instance Attribute Details
#graph_identifier ⇒ String
The unique identifier of the Neptune Analytics graph.
2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-neptunegraph/types.rb', line 2220 class ListQueriesInput < Struct.new( :graph_identifier, :max_results, :state) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to be fetched by the API.
2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-neptunegraph/types.rb', line 2220 class ListQueriesInput < Struct.new( :graph_identifier, :max_results, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
Filtered list of queries based on state.
2220 2221 2222 2223 2224 2225 2226 |
# File 'lib/aws-sdk-neptunegraph/types.rb', line 2220 class ListQueriesInput < Struct.new( :graph_identifier, :max_results, :state) SENSITIVE = [] include Aws::Structure end |