Class: Aws::NeptuneGraph::Waiters::ExportTaskCancelled
- Inherits:
-
Object
- Object
- Aws::NeptuneGraph::Waiters::ExportTaskCancelled
- Defined in:
- lib/aws-sdk-neptunegraph/waiters.rb,
sig/waiters.rbs
Overview
Wait until Export Task is Cancelled
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ExportTaskCancelled
constructor
A new instance of ExportTaskCancelled.
-
#wait(params = {}) ⇒ Types::GetExportTaskOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ExportTaskCancelled
Returns a new instance of ExportTaskCancelled.
95 96 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 95
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
127 128 129 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 127 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetExportTaskOutput
Returns a response object which responds to the following methods:
- #graph_id => String
- #role_arn => String
- #task_id => String
- #status => String
- #format => String
- #destination => String
- #kms_key_identifier => String
- #parquet_type => String
- #status_reason => String
- #export_task_details => Types::ExportTaskDetails
- #export_filter => Types::ExportFilter
122 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 122
def wait: (
|