Class: Aws::NeptuneGraph::Waiters::GraphSnapshotDeleted
- Inherits:
-
Object
- Object
- Aws::NeptuneGraph::Waiters::GraphSnapshotDeleted
- Defined in:
- lib/aws-sdk-neptunegraph/waiters.rb,
sig/waiters.rbs
Overview
Wait until GraphSnapshot is Deleted
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ GraphSnapshotDeleted
constructor
A new instance of GraphSnapshotDeleted.
-
#wait(params = {}) ⇒ Types::GetGraphSnapshotOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ GraphSnapshotDeleted
Returns a new instance of GraphSnapshotDeleted.
343 344 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 343
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
374 375 376 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 374 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetGraphSnapshotOutput
Returns a response object which responds to the following methods:
- #id => String
- #name => String
- #arn => String
- #source_graph_id => String
- #snapshot_create_time => Time
- #status => String
- #kms_key_identifier => String
369 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 369
def wait: (
|