Class: Aws::NeptuneGraph::Waiters::GraphStopped
- Inherits:
-
Object
- Object
- Aws::NeptuneGraph::Waiters::GraphStopped
- Defined in:
- lib/aws-sdk-neptunegraph/waiters.rb,
sig/waiters.rbs
Overview
Wait until Graph is Stopped
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ GraphStopped
constructor
A new instance of GraphStopped.
-
#wait(params = {}) ⇒ Types::GetGraphOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ GraphStopped
Returns a new instance of GraphStopped.
387 388 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 387
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
419 420 421 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 419 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetGraphOutput
Returns a response object which responds to the following methods:
- #id => String
- #name => String
- #arn => String
- #status => String
- #status_reason => String
- #create_time => Time
- #provisioned_memory => Integer
- #endpoint => String
- #public_connectivity => Boolean
- #vector_search_configuration => Types::VectorSearchConfiguration
- #replica_count => Integer
- #kms_key_identifier => String
- #source_snapshot_id => String
- #deletion_protection => Boolean
- #build_number => String
414 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 414
def wait: (
|