Class: Aws::NeptuneGraph::Waiters::ImportTaskSuccessful
- Inherits:
-
Object
- Object
- Aws::NeptuneGraph::Waiters::ImportTaskSuccessful
- Defined in:
- lib/aws-sdk-neptunegraph/waiters.rb
Overview
Wait until Import Task is Successful
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ImportTaskSuccessful
constructor
A new instance of ImportTaskSuccessful.
-
#wait(params = {}) ⇒ Types::GetImportTaskOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ImportTaskSuccessful
Returns a new instance of ImportTaskSuccessful.
477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 477 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 480, delay: 60, poller: Aws::Waiters::Poller.new( operation_name: :get_import_task, acceptors: [ { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "CANCELLING" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "CANCELLED" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "ROLLING_BACK" }, { "matcher" => "path", "argument" => "status", "state" => "failure", "expected" => "FAILED" }, { "matcher" => "path", "argument" => "status", "state" => "success", "expected" => "SUCCEEDED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
527 528 529 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 527 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetImportTaskOutput
Returns a response object which responds to the following methods:
-
#graph_id => String
-
#task_id => String
-
#source => String
-
#format => String
-
#parquet_type => String
-
#role_arn => String
-
#status => String
-
#import_options => Types::ImportOptions
-
#import_task_details => Types::ImportTaskDetails
-
#attempt_number => Integer
-
#status_reason => String
522 523 524 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 522 def wait(params = {}) @waiter.wait(client: @client, params: params) end |