Class: Aws::NeptuneGraph::Waiters::PrivateGraphEndpointDeleted
- Inherits:
-
Object
- Object
- Aws::NeptuneGraph::Waiters::PrivateGraphEndpointDeleted
- Defined in:
- lib/aws-sdk-neptunegraph/waiters.rb
Overview
Wait until PrivateGraphEndpoint is Deleted
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ PrivateGraphEndpointDeleted
constructor
A new instance of PrivateGraphEndpointDeleted.
-
#wait(params = {}) ⇒ Types::GetPrivateGraphEndpointOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ PrivateGraphEndpointDeleted
Returns a new instance of PrivateGraphEndpointDeleted.
591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 591 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 180, delay: 10, poller: Aws::Waiters::Poller.new( operation_name: :get_private_graph_endpoint, acceptors: [ { "matcher" => "path", "argument" => "status != 'DELETING'", "state" => "failure", "expected" => true }, { "matcher" => "error", "state" => "success", "expected" => "ResourceNotFoundException" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
622 623 624 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 622 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetPrivateGraphEndpointOutput
Returns a response object which responds to the following methods:
-
#vpc_id => String
-
#subnet_ids => Array<String>
-
#status => String
-
#vpc_endpoint_id => String
617 618 619 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 617 def wait(params = {}) @waiter.wait(client: @client, params: params) end |