Class: Aws::NeptuneGraph::Waiters::ImportTaskSuccessful
- Inherits:
-
Object
- Object
- Aws::NeptuneGraph::Waiters::ImportTaskSuccessful
- Defined in:
- lib/aws-sdk-neptunegraph/waiters.rb,
sig/waiters.rbs
Overview
Wait until Import Task is Successful
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ImportTaskSuccessful
constructor
A new instance of ImportTaskSuccessful.
-
#wait(params = {}) ⇒ Types::GetImportTaskOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ImportTaskSuccessful
Returns a new instance of ImportTaskSuccessful.
477 478 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 477
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
527 528 529 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 527 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetImportTaskOutput
Returns a response object which responds to the following methods:
- #graph_id => String
- #task_id => String
- #source => String
- #format => String
- #parquet_type => String
- #role_arn => String
- #status => String
- #import_options => Types::ImportOptions
- #import_task_details => Types::ImportTaskDetails
- #attempt_number => Integer
- #status_reason => String
522 |
# File 'lib/aws-sdk-neptunegraph/waiters.rb', line 522
def wait: (
|